==> Abjad-2.19.tar.gz: Abjad-2.19/abjad/tools/instrumenttools/BassFlute.py <==
# -*- coding: utf-8 -*-
from abjad.tools import indicatortools
from abjad.tools import markuptools
from abjad.tools import pitchtools
from abjad.tools.instrumenttools.Instrument import Instrument


class BassFlute(Instrument):
    r'''A bass flute.

    ::

        >>> staff = Staff("c'4 d'4 e'4 fs'4")
        >>> bass_flute = instrumenttools.BassFlute()
        >>> attach(bass_flute, staff)
        >>> show(staff) # doctest: +SKIP

    ..  doctest::

        >>> print(format(staff))
        \new Staff {
            \set Staff.instrumentName = \markup { "Bass flute" }
            \set Staff.shortInstrumentName = \markup { "Bass fl." }
            c'4
            d'4
            e'4
            fs'4
        }

    '''

    ### CLASS VARIABLES ###

    __slots__ = ()

    ### INITIALIZER ###

    def __init__(
        self,
        instrument_name='bass flute',
        short_instrument_name='bass fl.',
        instrument_name_markup=None,
        short_instrument_name_markup=None,
        allowable_clefs=None,
        pitch_range='[C3, C6]',
        sounding_pitch_of_written_middle_c='C3',
        ):
        Instrument.__init__(
            self,
            instrument_name=instrument_name,
            short_instrument_name=short_instrument_name,
            instrument_name_markup=instrument_name_markup,
            short_instrument_name_markup=short_instrument_name_markup,
            allowable_clefs=allowable_clefs,
            pitch_range=pitch_range,
            sounding_pitch_of_written_middle_c=\
                sounding_pitch_of_written_middle_c,
            )
        self._performer_names.extend([
            'wind player',
            'flautist',
            'flutist',
            ])

    ### PUBLIC PROPERTIES ###

    @property
    def allowable_clefs(self):
        r'''Gets bass flute's allowable clefs.

        ..  container:: example

            ::

                >>> bass_flute.allowable_clefs
                ClefInventory([Clef(name='treble')])

            ::

                >>> show(bass_flute.allowable_clefs) # doctest: +SKIP

        Returns clef inventory.
        '''
        return Instrument.allowable_clefs.fget(self)

    @property
    def instrument_name(self):
        r'''Gets bass flute's name.

        ..  container:: example

            ::

                >>> bass_flute.instrument_name
                'bass flute'

        Returns string.
        '''
        return Instrument.instrument_name.fget(self)

    @property
    def instrument_name_markup(self):
        r'''Gets bass flute's instrument name markup.

        ..  container:: example

            ::

                >>> bass_flute.instrument_name_markup
                Markup(contents=('Bass flute',))

            ::

                >>> show(bass_flute.instrument_name_markup) # doctest: +SKIP

        Returns markup.
        '''
        return Instrument.instrument_name_markup.fget(self)

    @property
    def pitch_range(self):
        r'''Gets bass flute's range.

        ..  container:: example

            ::

                >>> bass_flute.pitch_range
                PitchRange(range_string='[C3, C6]')

            ::

                >>> show(bass_flute.pitch_range) # doctest: +SKIP

        Returns pitch range.
        '''
        return Instrument.pitch_range.fget(self)

    @property
    def short_instrument_name(self):
        r'''Gets bass flute's short instrument name.

        ..  container:: example

            ::

                >>> bass_flute.short_instrument_name
                'bass fl.'

        Returns string.
        '''
        return Instrument.short_instrument_name.fget(self)

    @property
    def short_instrument_name_markup(self):
        r'''Gets bass flute's short instrument name markup.

        ..  container:: example

            ::

                >>> bass_flute.short_instrument_name_markup
                Markup(contents=('Bass fl.',))

            ::

                >>> show(bass_flute.short_instrument_name_markup) # doctest: +SKIP

        Returns markup.
        '''
        return Instrument.short_instrument_name_markup.fget(self)

    @property
    def sounding_pitch_of_written_middle_c(self):
        r'''Gets sounding pitch of bass_flute's written middle C.

        ..  container:: example

            ::

                >>> bass_flute.sounding_pitch_of_written_middle_c
                NamedPitch('c')

            ::

                >>> show(bass_flute.sounding_pitch_of_written_middle_c) # doctest: +SKIP

        Returns named pitch.
        '''
        return Instrument.sounding_pitch_of_written_middle_c.fget(self)

==> Abjad-2.20.tar.gz: Abjad-2.20/abjad/tools/instrumenttools/BassFlute.py <==
# -*- coding: utf-8 -*-
from abjad.tools import indicatortools
from abjad.tools import markuptools
from abjad.tools import pitchtools
from abjad.tools.instrumenttools.Instrument import Instrument


class BassFlute(Instrument):
    r'''A bass flute.

    ::

        >>> staff = Staff("c'4 d'4 e'4 fs'4")
        >>> bass_flute = instrumenttools.BassFlute()
        >>> attach(bass_flute, staff)
        >>> show(staff) # doctest: +SKIP

    ..  doctest::

        >>> f(staff)
        \new Staff {
            \set Staff.instrumentName = \markup { "Bass flute" }
            \set Staff.shortInstrumentName = \markup { "Bass fl." }
            c'4
            d'4
            e'4
            fs'4
        }

    '''

    ### CLASS VARIABLES ###

    __slots__ = ()

    ### INITIALIZER ###

    def __init__(
        self,
        instrument_name='bass flute',
        short_instrument_name='bass fl.',
        instrument_name_markup=None,
        short_instrument_name_markup=None,
        allowable_clefs=None,
        pitch_range='[C3, C6]',
        sounding_pitch_of_written_middle_c='C3',
        ):
        Instrument.__init__(
            self,
            instrument_name=instrument_name,
            short_instrument_name=short_instrument_name,
            instrument_name_markup=instrument_name_markup,
            short_instrument_name_markup=short_instrument_name_markup,
            allowable_clefs=allowable_clefs,
            pitch_range=pitch_range,
            sounding_pitch_of_written_middle_c=\
                sounding_pitch_of_written_middle_c,
            )
        self._performer_names.extend([
            'wind player',
            'flautist',
            'flutist',
            ])

    ### PUBLIC PROPERTIES ###

    @property
    def allowable_clefs(self):
        r'''Gets bass flute's allowable clefs.

        ..  container:: example

            ::

                >>> bass_flute.allowable_clefs
                ClefList([Clef(name='treble')])

            ::

                >>> show(bass_flute.allowable_clefs) # doctest: +SKIP

        Returns clef list.
        '''
        return Instrument.allowable_clefs.fget(self)

    @property
    def instrument_name(self):
        r'''Gets bass flute's name.

        ..  container:: example

            ::

                >>> bass_flute.instrument_name
                'bass flute'

        Returns string.
        '''
        return Instrument.instrument_name.fget(self)

    @property
    def instrument_name_markup(self):
        r'''Gets bass flute's instrument name markup.

        ..  container:: example

            ::

                >>> bass_flute.instrument_name_markup
                Markup(contents=['Bass flute'])

            ::

                >>> show(bass_flute.instrument_name_markup) # doctest: +SKIP

        Returns markup.
        '''
        return Instrument.instrument_name_markup.fget(self)

    @property
    def pitch_range(self):
        r'''Gets bass flute's range.

        ..  container:: example

            ::

                >>> bass_flute.pitch_range
                PitchRange(range_string='[C3, C6]')

            ::

                >>> show(bass_flute.pitch_range) # doctest: +SKIP

        Returns pitch range.
        '''
        return Instrument.pitch_range.fget(self)

    @property
    def short_instrument_name(self):
        r'''Gets bass flute's short instrument name.

        ..  container:: example

            ::

                >>> bass_flute.short_instrument_name
                'bass fl.'

        Returns string.
        '''
        return Instrument.short_instrument_name.fget(self)

    @property
    def short_instrument_name_markup(self):
        r'''Gets bass flute's short instrument name markup.

        ..  container:: example

            ::

                >>> bass_flute.short_instrument_name_markup
                Markup(contents=['Bass fl.'])

            ::

                >>> show(bass_flute.short_instrument_name_markup) # doctest: +SKIP

        Returns markup.
        '''
        return Instrument.short_instrument_name_markup.fget(self)

    @property
    def sounding_pitch_of_written_middle_c(self):
        r'''Gets sounding pitch of bass_flute's written middle C.

        ..  container:: example

            ::

                >>> bass_flute.sounding_pitch_of_written_middle_c
                NamedPitch('c')

            ::

                >>> show(bass_flute.sounding_pitch_of_written_middle_c) # doctest: +SKIP

        Returns named pitch.
        '''
        return Instrument.sounding_pitch_of_written_middle_c.fget(self)
